==> binnie-mods-1.11.2-2.1.0.19-sources.jar: binnie/botany/ceramic/brick/TileCeramicBrick.java <==
package binnie.botany.ceramic.brick;

import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.tileentity.TileEntity;

import binnie.botany.Botany;
import binnie.botany.genetics.EnumFlowerColor;
import binnie.core.block.TileEntityMetadata;

public class TileCeramicBrick extends TileEntity {
	private EnumFlowerColor colorFirst = EnumFlowerColor.Black;
	private EnumFlowerColor colorSecond = EnumFlowerColor.White;

	public void setColors(EnumFlowerColor colorFirst, EnumFlowerColor colorSecond) {
		this.colorFirst = colorFirst;
		this.colorSecond = colorSecond;
	}

	public boolean hasTwoColors() {
		return CeramicBrickType.VALUES[func_145832_p()].canDouble() && colorSecond != colorFirst;
	}

	public ItemStack getStack(int i) {
		ItemStack s = TileEntityMetadata.getItemStack(Botany.ceramicBrick, ordinal());
		s.func_190920_e(i);
		return s;
	}

	public int ordinal() {
		return colorFirst.ordinal() + colorSecond.ordinal() * 256 + func_145832_p() * 256 * 256;
	}

	public CeramicBrickPair pair() {
		return new CeramicBrickPair(colorFirst, colorSecond, CeramicBrickType.VALUES[func_145832_p()]);
	}

	public EnumFlowerColor getColorFirst() {
		return colorFirst;
	}

	public EnumFlowerColor getColorSecond() {
		return colorSecond;
	}

	@Override
	public NBTTagCompound func_189515_b(NBTTagCompound compound) {
		compound.func_74768_a("First", colorFirst.ordinal());
		compound.func_74768_a("Second", colorSecond.ordinal());
		return super.func_189515_b(compound);
	}

	@Override
	public NBTTagCompound func_189517_E_() {
		return func_189515_b(new NBTTagCompound());
	}

	@Override
	public void func_145839_a(NBTTagCompound compound) {
		super.func_145839_a(compound);
		if (compound.func_74764_b("First")) {
			colorFirst = EnumFlowerColor.VALUES[compound.func_74762_e("First")];
		}

		if (compound.func_74764_b("Second")) {
			colorSecond = EnumFlowerColor.VALUES[compound.func_74762_e("Second")];
		}
	}
}

==> binnie-mods-1.11.2-2.1.0.34-sources.jar: binnie/botany/ceramic/brick/TileCeramicBrick.java <==
package binnie.botany.ceramic.brick;

import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.tileentity.TileEntity;

import binnie.botany.Botany;
import binnie.botany.genetics.EnumFlowerColor;
import binnie.core.block.TileEntityMetadata;

public class TileCeramicBrick extends TileEntity {
	private EnumFlowerColor colorFirst = EnumFlowerColor.Black;
	private EnumFlowerColor colorSecond = EnumFlowerColor.White;

	public void setColors(EnumFlowerColor colorFirst, EnumFlowerColor colorSecond) {
		this.colorFirst = colorFirst;
		this.colorSecond = colorSecond;
	}

	public boolean hasTwoColors() {
		return CeramicBrickType.VALUES[func_145832_p()].canDouble() && colorSecond != colorFirst;
	}

	public ItemStack getStack(int i) {
		ItemStack s = TileEntityMetadata.getItemStack(Botany.gardening().ceramicBrick, ordinal());
		s.func_190920_e(i);
		return s;
	}

	public int ordinal() {
		return colorFirst.ordinal() + colorSecond.ordinal() * 256 + func_145832_p() * 256 * 256;
	}

	public CeramicBrickPair pair() {
		return new CeramicBrickPair(colorFirst, colorSecond, CeramicBrickType.VALUES[func_145832_p()]);
	}

	public EnumFlowerColor getColorFirst() {
		return colorFirst;
	}

	public EnumFlowerColor getColorSecond() {
		return colorSecond;
	}

	@Override
	public NBTTagCompound func_189515_b(NBTTagCompound compound) {
		compound.func_74768_a("First", colorFirst.ordinal());
		compound.func_74768_a("Second", colorSecond.ordinal());
		return super.func_189515_b(compound);
	}

	@Override
	public NBTTagCompound func_189517_E_() {
		return func_189515_b(new NBTTagCompound());
	}

	@Override
	public void func_145839_a(NBTTagCompound compound) {
		super.func_145839_a(compound);
		if (compound.func_74764_b("First")) {
			colorFirst = EnumFlowerColor.VALUES[compound.func_74762_e("First")];
		}

		if (compound.func_74764_b("Second")) {
			colorSecond = EnumFlowerColor.VALUES[compound.func_74762_e("Second")];
		}
	}
}
